hal: Branch 'master'
Danny Kukawka
dkukawka at kemper.freedesktop.org
Thu Aug 23 06:32:57 PDT 2007
fdi/policy/10osvendor/20-storage-methods.fdi | 2 +-
tools/hal-storage-mount.c | 3 ++-
2 files changed, 3 insertions(+), 2 deletions(-)
New commits:
diff-tree db8bd2dcb434384f3a24f8f0112343720be1b8a0 (from e8e3988db89e062210d9d97778775ae27e2b4815)
Author: Danny Kukawka <danny.kukawka at web.de>
Date: Thu Aug 23 15:32:50 2007 +0200
allow gid= for hfs, remove uid= for hfs+ and handle hfs like fat
This patch adds support for mountoption gid= to HFS partitions and handle
them like FAT partitions in hal-storage-mount.
Removed uid= mount option from HFS+ partitions because this filesystem
has per file uid support and it dont support this option.
diff --git a/fdi/policy/10osvendor/20-storage-methods.fdi b/fdi/policy/10osvendor/20-storage-methods.fdi
index 9e0645d..3304eaf 100644
--- a/fdi/policy/10osvendor/20-storage-methods.fdi
+++ b/fdi/policy/10osvendor/20-storage-methods.fdi
@@ -219,13 +219,13 @@
<!-- allow these mount options for hfs -->
<match key="volume.fstype" string="hfs">
+ <append key="volume.mount.valid_options" type="strlist">gid=</append>
<append key="volume.mount.valid_options" type="strlist">uid=</append>
<append key="volume.mount.valid_options" type="strlist">force</append>
</match>
<!-- allow these mount options for hfsplus -->
<match key="volume.fstype" string="hfsplus">
- <append key="volume.mount.valid_options" type="strlist">uid=</append>
<append key="volume.mount.valid_options" type="strlist">force</append>
</match>
diff --git a/tools/hal-storage-mount.c b/tools/hal-storage-mount.c
index 32d68e5..df8103a 100644
--- a/tools/hal-storage-mount.c
+++ b/tools/hal-storage-mount.c
@@ -718,11 +718,12 @@ handle_mount (LibHalContext *hal_ctx,
* (since these drives normally use vfat)
*/
if (volume != NULL) {
/* don't consider uid= on vfat, iso9660, udf change-uid for the purpose of policy
* (since these doesn't contain uid/gid bits)
*/
if (strcmp (libhal_volume_get_fstype (volume), "vfat") != 0 &&
strcmp (libhal_volume_get_fstype (volume), "iso9660") != 0 &&
+ strcmp (libhal_volume_get_fstype (volume), "hfs") != 0 &&
strcmp (libhal_volume_get_fstype (volume), "udf") != 0) {
pol_change_uid = wants_to_change_uid;
}
@@ -718,11 +718,12 @@ handle_mount (LibHalContext *hal_ctx,
*/
if (volume != NULL) {
- /* don't consider uid= on vfat, iso9660, udf change-uid for the purpose of policy
+ /* don't consider uid= on vfat, iso9660, hfs and udf change-uid for the purpose of policy
* (since these doesn't contain uid/gid bits)
*/
More information about the hal-commit
mailing list